-----------------------------------------------------------------------------

local AssessmentThreat = Assessment:NewModule("Threat", "AceEvent-2.0")
local Threat = AceLibrary("Threat-1.0")

-----------------------------------------------------------------------------

Assessment.TagData.targetthreat =
{
	method = function(data)
				local targetName = UnitName("target")
				if not targetName then return 0 end
				return Threat:GetThreat(data.key, targetName)
			 end,
	data			= { "target", "threat" },
	guaranteeResult = true,
	numeric			= true
}

-----------------------------------------------------------------------------

Assessment.DefaultDisplaySets["Threat"] =
{
	titleTag		= "Threat",
	listType		= "GroupMembers", 
	barValueTag		= "targetthreat", 
	filterType		= "NONZERO",
	fightIndex		= 1,
	barValueTextTag	= "[barValue]",
}

Assessment.DefaultDisplaySets["TPS"] =
{
	titleTag		= "TPS: [combattime:format(\"%.1f\")]s",
	listType		= "GroupMembers", 
	barValueTag		= "targetthreat / maximum(combatTime, 1)", 
	filterType		= "NONZERO",
	fightIndex		= 1,
	barValueTextTag	= "[barValue:format(\"%.1f\")]",
}

-----------------------------------------------------------------------------

function AssessmentThreat:OnInitialize()
end

function AssessmentThreat:OnEnable()
	self:RegisterEvent("PLAYER_TARGET_CHANGED", "OnPlayerTargetChanged")
	self:RegisterEvent("Threat_ThreatUpdated", "OnThreatUpdated")
end

function AssessmentThreat:OnDisable()
end

-----------------------------------------------------------------------------

function AssessmentThreat:OnPlayerTargetChanged()
	for data in self:IterateUpdateDataTables() do
		data.dataUpdateTimes.target = GetTime()
	end
end

function AssessmentThreat:OnThreatUpdated()
	for data in self:IterateUpdateDataTables() do
		data.dataUpdateTimes.threat = GetTime()
	end
end

-----------------------------------------------------------------------------
